@@ -38,8 +38,8 @@ impl<T> NapiAsyncWork<T> {
         env: NapiEnv,
         name: impl AsRef<str>,
         state: T,
-        execute: impl FnMut(&mut T) + Send,
-        complete: impl FnMut(NapiEnv, NapiStatus, T) -> NapiResult<()>,
+        execute: impl FnMut(&mut T) + Send + 'static,
+        complete: impl FnMut(NapiEnv, NapiStatus, T) -> NapiResult<()> + 'static,
     ) -> NapiResult<NapiAsyncWork<T>> {
         extern "C" fn napi_async_execute_callback<T>(env: NapiEnv, data: DataPointer) {
             unsafe {
